pub struct GenericElement { /* private fields */ }Trait Implementations
Sourceimpl AsRef<Element> for GenericElement
impl AsRef<Element> for GenericElement
Sourceimpl Debug for GenericElement
impl Debug for GenericElement
Sourceimpl From<Element> for GenericElement
impl From<Element> for GenericElement
Sourceimpl From<GenericElement> for Element
impl From<GenericElement> for Element
Sourcefn from(value: GenericElement) -> Self
fn from(value: GenericElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlAnchorElement> for GenericElement
impl From<HtmlAnchorElement> for GenericElement
Sourcefn from(element: HtmlAnchorElement) -> Self
fn from(element: HtmlAnchorElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlAreaElement> for GenericElement
impl From<HtmlAreaElement> for GenericElement
Sourcefn from(element: HtmlAreaElement) -> Self
fn from(element: HtmlAreaElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlAudioElement> for GenericElement
impl From<HtmlAudioElement> for GenericElement
Sourcefn from(element: HtmlAudioElement) -> Self
fn from(element: HtmlAudioElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlBaseElement> for GenericElement
impl From<HtmlBaseElement> for GenericElement
Sourcefn from(element: HtmlBaseElement) -> Self
fn from(element: HtmlBaseElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlBodyElement> for GenericElement
impl From<HtmlBodyElement> for GenericElement
Sourcefn from(element: HtmlBodyElement) -> Self
fn from(element: HtmlBodyElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlBrElement> for GenericElement
impl From<HtmlBrElement> for GenericElement
Sourcefn from(element: HtmlBrElement) -> Self
fn from(element: HtmlBrElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlButtonElement> for GenericElement
impl From<HtmlButtonElement> for GenericElement
Sourcefn from(element: HtmlButtonElement) -> Self
fn from(element: HtmlButtonElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlCanvasElement> for GenericElement
impl From<HtmlCanvasElement> for GenericElement
Sourcefn from(element: HtmlCanvasElement) -> Self
fn from(element: HtmlCanvasElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlDListElement> for GenericElement
impl From<HtmlDListElement> for GenericElement
Sourcefn from(element: HtmlDListElement) -> Self
fn from(element: HtmlDListElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlDataElement> for GenericElement
impl From<HtmlDataElement> for GenericElement
Sourcefn from(element: HtmlDataElement) -> Self
fn from(element: HtmlDataElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlDataListElement> for GenericElement
impl From<HtmlDataListElement> for GenericElement
Sourcefn from(element: HtmlDataListElement) -> Self
fn from(element: HtmlDataListElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlDetailsElement> for GenericElement
impl From<HtmlDetailsElement> for GenericElement
Sourcefn from(element: HtmlDetailsElement) -> Self
fn from(element: HtmlDetailsElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlDialogElement> for GenericElement
impl From<HtmlDialogElement> for GenericElement
Sourcefn from(element: HtmlDialogElement) -> Self
fn from(element: HtmlDialogElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlDivElement> for GenericElement
impl From<HtmlDivElement> for GenericElement
Sourcefn from(element: HtmlDivElement) -> Self
fn from(element: HtmlDivElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlEmbedElement> for GenericElement
impl From<HtmlEmbedElement> for GenericElement
Sourcefn from(element: HtmlEmbedElement) -> Self
fn from(element: HtmlEmbedElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlFieldSetElement> for GenericElement
impl From<HtmlFieldSetElement> for GenericElement
Sourcefn from(element: HtmlFieldSetElement) -> Self
fn from(element: HtmlFieldSetElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlFormElement> for GenericElement
impl From<HtmlFormElement> for GenericElement
Sourcefn from(element: HtmlFormElement) -> Self
fn from(element: HtmlFormElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlHeadElement> for GenericElement
impl From<HtmlHeadElement> for GenericElement
Sourcefn from(element: HtmlHeadElement) -> Self
fn from(element: HtmlHeadElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlHeadingElement> for GenericElement
impl From<HtmlHeadingElement> for GenericElement
Sourcefn from(element: HtmlHeadingElement) -> Self
fn from(element: HtmlHeadingElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlHrElement> for GenericElement
impl From<HtmlHrElement> for GenericElement
Sourcefn from(element: HtmlHrElement) -> Self
fn from(element: HtmlHrElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlHtmlElement> for GenericElement
impl From<HtmlHtmlElement> for GenericElement
Sourcefn from(element: HtmlHtmlElement) -> Self
fn from(element: HtmlHtmlElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlIFrameElement> for GenericElement
impl From<HtmlIFrameElement> for GenericElement
Sourcefn from(element: HtmlIFrameElement) -> Self
fn from(element: HtmlIFrameElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlImageElement> for GenericElement
impl From<HtmlImageElement> for GenericElement
Sourcefn from(element: HtmlImageElement) -> Self
fn from(element: HtmlImageElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlInputElement> for GenericElement
impl From<HtmlInputElement> for GenericElement
Sourcefn from(element: HtmlInputElement) -> Self
fn from(element: HtmlInputElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlLabelElement> for GenericElement
impl From<HtmlLabelElement> for GenericElement
Sourcefn from(element: HtmlLabelElement) -> Self
fn from(element: HtmlLabelElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlLegendElement> for GenericElement
impl From<HtmlLegendElement> for GenericElement
Sourcefn from(element: HtmlLegendElement) -> Self
fn from(element: HtmlLegendElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlLiElement> for GenericElement
impl From<HtmlLiElement> for GenericElement
Sourcefn from(element: HtmlLiElement) -> Self
fn from(element: HtmlLiElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlLinkElement> for GenericElement
impl From<HtmlLinkElement> for GenericElement
Sourcefn from(element: HtmlLinkElement) -> Self
fn from(element: HtmlLinkElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlMapElement> for GenericElement
impl From<HtmlMapElement> for GenericElement
Sourcefn from(element: HtmlMapElement) -> Self
fn from(element: HtmlMapElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlMetaElement> for GenericElement
impl From<HtmlMetaElement> for GenericElement
Sourcefn from(element: HtmlMetaElement) -> Self
fn from(element: HtmlMetaElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlMeterElement> for GenericElement
impl From<HtmlMeterElement> for GenericElement
Sourcefn from(element: HtmlMeterElement) -> Self
fn from(element: HtmlMeterElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlModElement> for GenericElement
impl From<HtmlModElement> for GenericElement
Sourcefn from(element: HtmlModElement) -> Self
fn from(element: HtmlModElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlOListElement> for GenericElement
impl From<HtmlOListElement> for GenericElement
Sourcefn from(element: HtmlOListElement) -> Self
fn from(element: HtmlOListElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlObjectElement> for GenericElement
impl From<HtmlObjectElement> for GenericElement
Sourcefn from(element: HtmlObjectElement) -> Self
fn from(element: HtmlObjectElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlOptGroupElement> for GenericElement
impl From<HtmlOptGroupElement> for GenericElement
Sourcefn from(element: HtmlOptGroupElement) -> Self
fn from(element: HtmlOptGroupElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlOptionElement> for GenericElement
impl From<HtmlOptionElement> for GenericElement
Sourcefn from(element: HtmlOptionElement) -> Self
fn from(element: HtmlOptionElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlOutputElement> for GenericElement
impl From<HtmlOutputElement> for GenericElement
Sourcefn from(element: HtmlOutputElement) -> Self
fn from(element: HtmlOutputElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlParagraphElement> for GenericElement
impl From<HtmlParagraphElement> for GenericElement
Sourcefn from(element: HtmlParagraphElement) -> Self
fn from(element: HtmlParagraphElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlParamElement> for GenericElement
impl From<HtmlParamElement> for GenericElement
Sourcefn from(element: HtmlParamElement) -> Self
fn from(element: HtmlParamElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlPictureElement> for GenericElement
impl From<HtmlPictureElement> for GenericElement
Sourcefn from(element: HtmlPictureElement) -> Self
fn from(element: HtmlPictureElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlPreElement> for GenericElement
impl From<HtmlPreElement> for GenericElement
Sourcefn from(element: HtmlPreElement) -> Self
fn from(element: HtmlPreElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlProgressElement> for GenericElement
impl From<HtmlProgressElement> for GenericElement
Sourcefn from(element: HtmlProgressElement) -> Self
fn from(element: HtmlProgressElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlQuoteElement> for GenericElement
impl From<HtmlQuoteElement> for GenericElement
Sourcefn from(element: HtmlQuoteElement) -> Self
fn from(element: HtmlQuoteElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlScriptElement> for GenericElement
impl From<HtmlScriptElement> for GenericElement
Sourcefn from(element: HtmlScriptElement) -> Self
fn from(element: HtmlScriptElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlSelectElement> for GenericElement
impl From<HtmlSelectElement> for GenericElement
Sourcefn from(element: HtmlSelectElement) -> Self
fn from(element: HtmlSelectElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlSlotElement> for GenericElement
impl From<HtmlSlotElement> for GenericElement
Sourcefn from(element: HtmlSlotElement) -> Self
fn from(element: HtmlSlotElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlSourceElement> for GenericElement
impl From<HtmlSourceElement> for GenericElement
Sourcefn from(element: HtmlSourceElement) -> Self
fn from(element: HtmlSourceElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlSpanElement> for GenericElement
impl From<HtmlSpanElement> for GenericElement
Sourcefn from(element: HtmlSpanElement) -> Self
fn from(element: HtmlSpanElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlStyleElement> for GenericElement
impl From<HtmlStyleElement> for GenericElement
Sourcefn from(element: HtmlStyleElement) -> Self
fn from(element: HtmlStyleElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlTableCaptionElement> for GenericElement
impl From<HtmlTableCaptionElement> for GenericElement
Sourcefn from(element: HtmlTableCaptionElement) -> Self
fn from(element: HtmlTableCaptionElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlTableCellElement> for GenericElement
impl From<HtmlTableCellElement> for GenericElement
Sourcefn from(element: HtmlTableCellElement) -> Self
fn from(element: HtmlTableCellElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlTableColElement> for GenericElement
impl From<HtmlTableColElement> for GenericElement
Sourcefn from(element: HtmlTableColElement) -> Self
fn from(element: HtmlTableColElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlTableElement> for GenericElement
impl From<HtmlTableElement> for GenericElement
Sourcefn from(element: HtmlTableElement) -> Self
fn from(element: HtmlTableElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlTableRowElement> for GenericElement
impl From<HtmlTableRowElement> for GenericElement
Sourcefn from(element: HtmlTableRowElement) -> Self
fn from(element: HtmlTableRowElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlTableSectionElement> for GenericElement
impl From<HtmlTableSectionElement> for GenericElement
Sourcefn from(element: HtmlTableSectionElement) -> Self
fn from(element: HtmlTableSectionElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlTemplateElement> for GenericElement
impl From<HtmlTemplateElement> for GenericElement
Sourcefn from(element: HtmlTemplateElement) -> Self
fn from(element: HtmlTemplateElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlTextAreaElement> for GenericElement
impl From<HtmlTextAreaElement> for GenericElement
Sourcefn from(element: HtmlTextAreaElement) -> Self
fn from(element: HtmlTextAreaElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlTimeElement> for GenericElement
impl From<HtmlTimeElement> for GenericElement
Sourcefn from(element: HtmlTimeElement) -> Self
fn from(element: HtmlTimeElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlTitleElement> for GenericElement
impl From<HtmlTitleElement> for GenericElement
Sourcefn from(element: HtmlTitleElement) -> Self
fn from(element: HtmlTitleElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlTrackElement> for GenericElement
impl From<HtmlTrackElement> for GenericElement
Sourcefn from(element: HtmlTrackElement) -> Self
fn from(element: HtmlTrackElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlUListElement> for GenericElement
impl From<HtmlUListElement> for GenericElement
Sourcefn from(element: HtmlUListElement) -> Self
fn from(element: HtmlUListElement) -> Self
Converts to this type from the input type.
Sourceimpl From<HtmlVideoElement> for GenericElement
impl From<HtmlVideoElement> for GenericElement
Sourcefn from(element: HtmlVideoElement) -> Self
fn from(element: HtmlVideoElement) -> Self
Converts to this type from the input type.
Sourceimpl TryFrom<GenericElement> for GenericHtmlElement
impl TryFrom<GenericElement> for GenericHtmlElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlAnchorElement
impl TryFrom<GenericElement> for HtmlAnchorElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlAreaElement
impl TryFrom<GenericElement> for HtmlAreaElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlAudioElement
impl TryFrom<GenericElement> for HtmlAudioElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlBaseElement
impl TryFrom<GenericElement> for HtmlBaseElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlBodyElement
impl TryFrom<GenericElement> for HtmlBodyElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlBrElement
impl TryFrom<GenericElement> for HtmlBrElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlButtonElement
impl TryFrom<GenericElement> for HtmlButtonElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlCanvasElement
impl TryFrom<GenericElement> for HtmlCanvasElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlDListElement
impl TryFrom<GenericElement> for HtmlDListElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlDataElement
impl TryFrom<GenericElement> for HtmlDataElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlDataListElement
impl TryFrom<GenericElement> for HtmlDataListElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlDetailsElement
impl TryFrom<GenericElement> for HtmlDetailsElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlDialogElement
impl TryFrom<GenericElement> for HtmlDialogElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlDivElement
impl TryFrom<GenericElement> for HtmlDivElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlEmbedElement
impl TryFrom<GenericElement> for HtmlEmbedElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlFieldSetElement
impl TryFrom<GenericElement> for HtmlFieldSetElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlFormElement
impl TryFrom<GenericElement> for HtmlFormElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlHeadElement
impl TryFrom<GenericElement> for HtmlHeadElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlHeadingElement
impl TryFrom<GenericElement> for HtmlHeadingElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlHrElement
impl TryFrom<GenericElement> for HtmlHrElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlHtmlElement
impl TryFrom<GenericElement> for HtmlHtmlElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlIFrameElement
impl TryFrom<GenericElement> for HtmlIFrameElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlImageElement
impl TryFrom<GenericElement> for HtmlImageElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlInputElement
impl TryFrom<GenericElement> for HtmlInputElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlLabelElement
impl TryFrom<GenericElement> for HtmlLabelElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlLegendElement
impl TryFrom<GenericElement> for HtmlLegendElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlLiElement
impl TryFrom<GenericElement> for HtmlLiElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlLinkElement
impl TryFrom<GenericElement> for HtmlLinkElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlMapElement
impl TryFrom<GenericElement> for HtmlMapElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlMetaElement
impl TryFrom<GenericElement> for HtmlMetaElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlMeterElement
impl TryFrom<GenericElement> for HtmlMeterElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlModElement
impl TryFrom<GenericElement> for HtmlModElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlOListElement
impl TryFrom<GenericElement> for HtmlOListElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlObjectElement
impl TryFrom<GenericElement> for HtmlObjectElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlOptGroupElement
impl TryFrom<GenericElement> for HtmlOptGroupElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlOptionElement
impl TryFrom<GenericElement> for HtmlOptionElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlOutputElement
impl TryFrom<GenericElement> for HtmlOutputElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlParagraphElement
impl TryFrom<GenericElement> for HtmlParagraphElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlParamElement
impl TryFrom<GenericElement> for HtmlParamElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlPictureElement
impl TryFrom<GenericElement> for HtmlPictureElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlPreElement
impl TryFrom<GenericElement> for HtmlPreElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlProgressElement
impl TryFrom<GenericElement> for HtmlProgressElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlQuoteElement
impl TryFrom<GenericElement> for HtmlQuoteElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlScriptElement
impl TryFrom<GenericElement> for HtmlScriptElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlSelectElement
impl TryFrom<GenericElement> for HtmlSelectElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlSlotElement
impl TryFrom<GenericElement> for HtmlSlotElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlSourceElement
impl TryFrom<GenericElement> for HtmlSourceElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlSpanElement
impl TryFrom<GenericElement> for HtmlSpanElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlStyleElement
impl TryFrom<GenericElement> for HtmlStyleElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlTableCaptionElement
impl TryFrom<GenericElement> for HtmlTableCaptionElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlTableCellElement
impl TryFrom<GenericElement> for HtmlTableCellElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlTableColElement
impl TryFrom<GenericElement> for HtmlTableColElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlTableElement
impl TryFrom<GenericElement> for HtmlTableElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlTableRowElement
impl TryFrom<GenericElement> for HtmlTableRowElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlTableSectionElement
impl TryFrom<GenericElement> for HtmlTableSectionElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlTemplateElement
impl TryFrom<GenericElement> for HtmlTemplateElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlTextAreaElement
impl TryFrom<GenericElement> for HtmlTextAreaElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlTimeElement
impl TryFrom<GenericElement> for HtmlTimeElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlTitleElement
impl TryFrom<GenericElement> for HtmlTitleElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlTrackElement
impl TryFrom<GenericElement> for HtmlTrackElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlUListElement
impl TryFrom<GenericElement> for HtmlUListElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericElement> for HtmlVideoElement
impl TryFrom<GenericElement> for HtmlVideoElement
Sourcetype Error = InvalidCast<GenericElement>
type Error = InvalidCast<GenericElement>
The type returned in the event of a conversion error.
Sourceimpl TryFrom<GenericNode> for GenericElement
impl TryFrom<GenericNode> for GenericElement
Sourcetype Error = InvalidCast<GenericNode>
type Error = InvalidCast<GenericNode>
The type returned in the event of a conversion error.